@@ -1,8 +1,22 @@
 from abc import ABCMeta
-from typing import Any, Callable, Dict, List, Optional, Sequence, Union, cast
+import inspect
+import warnings
+from typing import Any, Callable, Dict, List, Optional, Sequence, Union, Type, cast
+from pydantic import BaseModel
 
-from llama_index.core.agent.workflow.base_agent import BaseWorkflowAgent
+from llama_index.core.agent.utils import generate_structured_response
+from llama_index.core.agent.workflow.base_agent import (
+    BaseWorkflowAgent,
+    DEFAULT_AGENT_NAME,
+    DEFAULT_AGENT_DESCRIPTION,
+    DEFAULT_MAX_ITERATIONS,
+)
 from llama_index.core.agent.workflow.function_agent import FunctionAgent
+from llama_index.core.agent.workflow.prompts import (
+    DEFAULT_HANDOFF_PROMPT,
+    DEFAULT_HANDOFF_OUTPUT_PROMPT,
+    DEFAULT_STATE_PROMPT,
+)
 from llama_index.core.agent.workflow.react_agent import ReActAgent
 from llama_index.core.agent.workflow.workflow_events import (
     ToolCall,
@@ -10,8 +24,10 @@ from llama_index.core.agent.workflow.workflow_events import (
     AgentInput,
     AgentSetup,
     AgentOutput,
+    AgentWorkflowStartEvent,
+    AgentStreamStructuredOutput,
 )
-from llama_index.core.llms import ChatMessage
+from llama_index.core.llms import ChatMessage, TextBlock
 from llama_index.core.llms.llm import LLM
 from llama_index.core.memory import BaseMemory, ChatMemoryBuffer
 from llama_index.core.prompts import BasePromptTemplate, PromptTemplate
@@ -30,6 +46,7 @@ from llama_index.core.workflow import (
     StopEvent,
     Workflow,
     step,
+    WorkflowRuntimeError,
 )
 from llama_index.core.workflow.checkpointer import CheckpointCallback
 from llama_index.core.workflow.handler import WorkflowHandler
@@ -37,33 +54,22 @@ from llama_index.core.workflow.workflow import WorkflowMeta
 from llama_index.core.settings import Settings
 
 
-DEFAULT_HANDOFF_PROMPT = """Useful for handing off to another agent.
-If you are currently not equipped to handle the user's request, or another agent is better suited to handle the request, please hand off to the appropriate agent.
-
-Currently available agents:
-{agent_info}
-"""
-
-DEFAULT_STATE_PROMPT = """Current state:
-{state}
-
-Current message:
-{msg}
-"""
-
-DEFAULT_HANDOFF_OUTPUT_PROMPT = "Agent {to_agent} is now handling the request due to the following reason: {reason}.\nPlease continue with the current request."
-
-
 async def handoff(ctx: Context, to_agent: str, reason: str) -> str:
     """Handoff control of that chat to the given agent."""
-    agents: list[str] = await ctx.get("agents")
-    current_agent_name: str = await ctx.get("current_agent_name")
+    agents: list[str] = await ctx.store.get("agents")
+    current_agent_name: str = await ctx.store.get("current_agent_name")
+    can_handoff_to: dict[str, list[str]] = await ctx.store.get("can_handoff_to")
     if to_agent not in agents:
         valid_agents = ", ".join([x for x in agents if x != current_agent_name])
         return f"Agent {to_agent} not found. Please select a valid agent to hand off to. Valid agents: {valid_agents}"
 
-    await ctx.set("next_agent", to_agent)
-    handoff_output_prompt = await ctx.get(
+    if can_handoff_to.get(
+        current_agent_name, []
+    ) is not None and to_agent not in can_handoff_to.get(current_agent_name, []):
+        return f"Agent {to_agent} cannot hand off to {current_agent_name}. Please select a valid agent to hand off to."
+
+    await ctx.store.set("next_agent", to_agent)
+    handoff_output_prompt = await ctx.store.get(
         "handoff_output_prompt", default=DEFAULT_HANDOFF_OUTPUT_PROMPT
     )
 
@@ -86,12 +92,34 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         handoff_output_prompt: Optional[Union[str, BasePromptTemplate]] = None,
         state_prompt: Optional[Union[str, BasePromptTemplate]] = None,
         timeout: Optional[float] = None,
+        output_cls: Optional[Type[BaseModel]] = None,
+        structured_output_fn: Optional[
+            Callable[[List[ChatMessage]], Dict[str, Any]]
+        ] = None,
         **workflow_kwargs: Any,
     ):
         super().__init__(timeout=timeout, **workflow_kwargs)
         if not agents:
             raise ValueError("At least one agent must be provided")
 
+        # Raise an error if any agent has no name or no description
+        if len(agents) > 1 and any(
+            agent.name == DEFAULT_AGENT_NAME for agent in agents
+        ):
+            raise ValueError("All agents must have a name in a multi-agent workflow")
+
+        if len(agents) > 1 and any(
+            agent.description == DEFAULT_AGENT_DESCRIPTION for agent in agents
+        ):
+            raise ValueError(
+                "All agents must have a description in a multi-agent workflow"
+            )
+
+        if any(agent.initial_state for agent in agents):
+            raise ValueError(
+                "Initial state is not supported per-agent in AgentWorkflow"
+            )
+
         self.agents = {cfg.name: cfg for cfg in agents}
         if len(agents) == 1:
             root_agent = agents[0].name
@@ -135,6 +163,11 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
                 raise ValueError("State prompt must contain {state} and {msg}")
         self.state_prompt = state_prompt
 
+        self.output_cls = output_cls
+        self.structured_output_fn = structured_output_fn
+        if output_cls is not None and structured_output_fn is not None:
+            self.structured_output_fn = None
+
     def _get_prompts(self) -> PromptDictType:
         """Get prompts."""
         return {
@@ -166,6 +199,10 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         self, current_agent: BaseWorkflowAgent
     ) -> Optional[AsyncBaseTool]:
         """Creates a handoff tool for the given agent."""
+        # Do not create a handoff tool if there is only one agent
+        if len(self.agents) == 1:
+            return None
+
         agent_info = {cfg.name: cfg.description for cfg in self.agents.values()}
 
         # Filter out agents that the current agent cannot handoff to
@@ -213,22 +250,41 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
 
     async def _init_context(self, ctx: Context, ev: StartEvent) -> None:
         """Initialize the context once, if needed."""
-        if not await ctx.get("memory", default=None):
+        if not await ctx.store.get("memory", default=None):
             default_memory = ev.get("memory", default=None)
             default_memory = default_memory or ChatMemoryBuffer.from_defaults(
                 llm=self.agents[self.root_agent].llm or Settings.llm
             )
-            await ctx.set("memory", default_memory)
-        if not await ctx.get("agents", default=None):
-            await ctx.set("agents", list(self.agents.keys()))
-        if not await ctx.get("state", default=None):
-            await ctx.set("state", self.initial_state)
-        if not await ctx.get("current_agent_name", default=None):
-            await ctx.set("current_agent_name", self.root_agent)
-        if not await ctx.get("handoff_output_prompt", default=None):
-            await ctx.set(
+            await ctx.store.set("memory", default_memory)
+        if not await ctx.store.get("agents", default=None):
+            await ctx.store.set("agents", list(self.agents.keys()))
+        if not await ctx.store.get("can_handoff_to", default=None):
+            await ctx.store.set(
+                "can_handoff_to",
+                {
+                    agent: agent_cfg.can_handoff_to
+                    for agent, agent_cfg in self.agents.items()
+                },
+            )
+        if not await ctx.store.get("state", default=None):
+            await ctx.store.set("state", self.initial_state)
+        if not await ctx.store.get("current_agent_name", default=None):
+            await ctx.store.set("current_agent_name", self.root_agent)
+        if not await ctx.store.get("handoff_output_prompt", default=None):
+            await ctx.store.set(
                 "handoff_output_prompt", self.handoff_output_prompt.get_template()
             )
+        if not await ctx.store.get("max_iterations", default=None):
+            max_iterations = (
+                ev.get("max_iterations", default=None) or DEFAULT_MAX_ITERATIONS
+            )
+            await ctx.store.set("max_iterations", max_iterations)
+
+        # Reset the number of iterations
+        await ctx.store.set("num_iterations", 0)
+
+        # always set to false initially
+        await ctx.store.set("formatted_input_with_state", False)
 
     async def _call_tool(
         self,
@@ -238,14 +294,20 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
     ) -> ToolOutput:
         """Call the given tool with the given input."""
         try:
-            if isinstance(tool, FunctionTool) and tool.requires_context:
-                tool_output = await tool.acall(ctx=ctx, **tool_input)
+            if (
+                isinstance(tool, FunctionTool)
+                and tool.requires_context
+                and tool.ctx_param_name is not None
+            ):
+                new_tool_input = {**tool_input}
+                new_tool_input[tool.ctx_param_name] = ctx
+                tool_output = await tool.acall(**new_tool_input)
             else:
                 tool_output = await tool.acall(**tool_input)
         except Exception as e:
             tool_output = ToolOutput(
                 content=str(e),
-                tool_name=tool.metadata.name,
+                tool_name=tool.metadata.get_name(),
                 raw_input=tool_input,
                 raw_output=str(e),
                 is_error=True,
@@ -254,7 +316,7 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         return tool_output
 
     @step
-    async def init_run(self, ctx: Context, ev: StartEvent) -> AgentInput:
+    async def init_run(self, ctx: Context, ev: AgentWorkflowStartEvent) -> AgentInput:
         """Sets up the workflow and validates inputs."""
         await self._init_context(ctx, ev)
 
@@ -266,39 +328,46 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
             user_msg = ChatMessage(role="user", content=user_msg)
 
         # Add messages to memory
-        memory: BaseMemory = await ctx.get("memory")
+        memory: BaseMemory = await ctx.store.get("memory")
 
         # First set chat history if it exists
         if chat_history:
-            memory.set(chat_history)
+            await memory.aset(chat_history)
 
         # Then add user message if it exists
-        current_state = await ctx.get("state")
         if user_msg:
-            # Add the state to the user message if it exists
-            if current_state:
-                user_msg.content = self.state_prompt.format(
-                    state=current_state, msg=user_msg.content
-                )
             await memory.aput(user_msg)
-            await ctx.set("user_msg_str", user_msg.content)
-        elif chat_history:
+            content_str = "\n".join(
+                [
+                    block.text
+                    for block in user_msg.blocks
+                    if isinstance(block, TextBlock)
+                ]
+            )
+            await ctx.store.set("user_msg_str", content_str)
+        elif chat_history and not all(
+            message.role == "system" for message in chat_history
+        ):
             # If no user message, use the last message from chat history as user_msg_str
-            last_msg = chat_history[-1].content or ""
-            await ctx.set("user_msg_str", last_msg)
-
-            if current_state:
-                chat_history[-1].content = self.state_prompt.format(
-                    state=current_state, msg=chat_history[-1].content
-                )
+            user_hist: List[ChatMessage] = [
+                msg for msg in chat_history if msg.role == "user"
+            ]
+            content_str = "\n".join(
+                [
+                    block.text
+                    for block in user_hist[-1].blocks
+                    if isinstance(block, TextBlock)
+                ]
+            )
+            await ctx.store.set("user_msg_str", content_str)
         else:
             raise ValueError("Must provide either user_msg or chat_history")
 
         # Get all messages from memory
-        input_messages = memory.get()
+        input_messages = await memory.aget()
 
         # send to the current agent
-        current_agent_name: str = await ctx.get("current_agent_name")
+        current_agent_name: str = await ctx.store.get("current_agent_name")
         return AgentInput(input=input_messages, current_agent_name=current_agent_name)
 
     @step
@@ -306,7 +375,7 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         """Main agent handling logic."""
         current_agent_name = ev.current_agent_name
         agent = self.agents[current_agent_name]
-        llm_input = ev.input
+        llm_input = [*ev.input]
 
         if agent.system_prompt:
             llm_input = [
@@ -314,6 +383,18 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
                 *llm_input,
             ]
 
+        state = await ctx.store.get("state", default=None)
+        formatted_input_with_state = await ctx.store.get(
+            "formatted_input_with_state", default=False
+        )
+        if state and not formatted_input_with_state:
+            # update last message with current state
+            for block in llm_input[-1].blocks[::-1]:
+                if isinstance(block, TextBlock):
+                    block.text = self.state_prompt.format(state=state, msg=block.text)
+                    break
+            await ctx.store.set("formatted_input_with_state", True)
+
         return AgentSetup(
             input=llm_input,
             current_agent_name=ev.current_agent_name,
@@ -322,9 +403,10 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
     @step
     async def run_agent_step(self, ctx: Context, ev: AgentSetup) -> AgentOutput:
         """Run the agent."""
-        memory: BaseMemory = await ctx.get("memory")
+        memory: BaseMemory = await ctx.store.get("memory")
         agent = self.agents[ev.current_agent_name]
-        tools = await self.get_tools(ev.current_agent_name, ev.input[-1].content or "")
+        user_msg_str = await ctx.store.get("user_msg_str")
+        tools = await self.get_tools(ev.current_agent_name, user_msg_str or "")
 
         agent_output = await agent.take_step(
             ctx,
@@ -339,21 +421,89 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
     @step
     async def parse_agent_output(
         self, ctx: Context, ev: AgentOutput
-    ) -> Union[StopEvent, ToolCall, None]:
+    ) -> Union[StopEvent, AgentInput, ToolCall, None]:
+        max_iterations = await ctx.store.get(
+            "max_iterations", default=DEFAULT_MAX_ITERATIONS
+        )
+        num_iterations = await ctx.store.get("num_iterations", default=0)
+        num_iterations += 1
+        await ctx.store.set("num_iterations", num_iterations)
+
+        if num_iterations >= max_iterations:
+            raise WorkflowRuntimeError(
+                f"Max iterations of {max_iterations} reached! Either something went wrong, or you can "
+                "increase the max iterations with `.run(.., max_iterations=...)`"
+            )
+
+        memory: BaseMemory = await ctx.store.get("memory")
+
+        if ev.retry_messages:
+            # Retry with the given messages to let the LLM fix potential errors
+            history = await memory.aget()
+            user_msg_str = await ctx.store.get("user_msg_str")
+            agent_name: str = await ctx.store.get("current_agent_name")
+
+            return AgentInput(
+                input=[
+                    *history,
+                    ChatMessage(role="user", content=user_msg_str),
+                    *ev.retry_messages,
+                ],
+                current_agent_name=agent_name,
+            )
+
         if not ev.tool_calls:
             agent = self.agents[ev.current_agent_name]
-            memory: BaseMemory = await ctx.get("memory")
+            memory = await ctx.store.get("memory")
+            # important: messages should always be fetched after calling finalize, otherwise they do not contain the agent's response
             output = await agent.finalize(ctx, ev, memory)
+            messages = await memory.aget()
 
-            cur_tool_calls: List[ToolCallResult] = await ctx.get(
+            cur_tool_calls: List[ToolCallResult] = await ctx.store.get(
                 "current_tool_calls", default=[]
             )
             output.tool_calls.extend(cur_tool_calls)  # type: ignore
-            await ctx.set("current_tool_calls", [])
+            await ctx.store.set("current_tool_calls", [])
+
+            if self.structured_output_fn is not None:
+                try:
+                    if inspect.iscoroutinefunction(self.structured_output_fn):
+                        output.structured_response = await self.structured_output_fn(
+                            messages
+                        )
+                    else:
+                        output.structured_response = cast(
+                            Dict[str, Any], self.structured_output_fn(messages)
+                        )
+                    ctx.write_event_to_stream(
+                        AgentStreamStructuredOutput(output=output.structured_response)
+                    )
+                except Exception as e:
+                    warnings.warn(
+                        f"There was a problem with the generation of the structured output: {e}"
+                    )
+            if self.output_cls is not None:
+                try:
+                    llm_input = [*messages]
+                    if agent.system_prompt:
+                        llm_input = [
+                            ChatMessage(role="system", content=agent.system_prompt),
+                            *llm_input,
+                        ]
+                    output.structured_response = await generate_structured_response(
+                        messages=llm_input, llm=agent.llm, output_cls=self.output_cls
+                    )
+                    ctx.write_event_to_stream(
+                        AgentStreamStructuredOutput(output=output.structured_response)
+                    )
+                except Exception as e:
+                    warnings.warn(
+                        f"There was a problem with the generation of the structured output: {e}"
+                    )
 
             return StopEvent(result=output)
 
-        await ctx.set("num_tool_calls", len(ev.tool_calls))
+        await ctx.store.set("num_tool_calls", len(ev.tool_calls))
 
         for tool_call in ev.tool_calls:
             ctx.send_event(
@@ -377,7 +527,7 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
             )
         )
 
-        current_agent_name = await ctx.get("current_agent_name")
+        current_agent_name = await ctx.store.get("current_agent_name")
         tools = await self.get_tools(current_agent_name, ev.tool_name)
         tools_by_name = {tool.metadata.name: tool for tool in tools}
         if ev.tool_name not in tools_by_name:
@@ -409,7 +559,7 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         self, ctx: Context, ev: ToolCallResult
     ) -> Union[AgentInput, StopEvent, None]:
         """Aggregate tool results and return the next agent input."""
-        num_tool_calls = await ctx.get("num_tool_calls", default=0)
+        num_tool_calls = await ctx.store.get("num_tool_calls", default=0)
         if num_tool_calls == 0:
             raise ValueError("No tool calls found, cannot aggregate results.")
 
@@ -419,33 +569,36 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         if not tool_call_results:
             return None
 
-        memory: BaseMemory = await ctx.get("memory")
-        agent_name: str = await ctx.get("current_agent_name")
+        memory: BaseMemory = await ctx.store.get("memory")
+        agent_name: str = await ctx.store.get("current_agent_name")
         agent: BaseWorkflowAgent = self.agents[agent_name]
 
         # track tool calls made during a .run() call
-        cur_tool_calls: List[ToolCallResult] = await ctx.get(
+        cur_tool_calls: List[ToolCallResult] = await ctx.store.get(
             "current_tool_calls", default=[]
         )
         cur_tool_calls.extend(tool_call_results)
-        await ctx.set("current_tool_calls", cur_tool_calls)
+        await ctx.store.set("current_tool_calls", cur_tool_calls)
 
         await agent.handle_tool_call_results(ctx, tool_call_results, memory)
 
         # set the next agent, if needed
         # the handoff tool sets this
-        next_agent_name = await ctx.get("next_agent", default=None)
+        next_agent_name = await ctx.store.get("next_agent", default=None)
         if next_agent_name:
-            await ctx.set("current_agent_name", next_agent_name)
+            await ctx.store.set("current_agent_name", next_agent_name)
+            await ctx.store.set("next_agent", None)
 
         if any(
-            tool_call_result.return_direct for tool_call_result in tool_call_results
+            tool_call_result.return_direct and not tool_call_result.tool_output.is_error
+            for tool_call_result in tool_call_results
         ):
-            # if any tool calls return directly, take the first one
+            # if any tool calls return directly and it's not an error tool call, take the first one
             return_direct_tool = next(
                 tool_call_result
                 for tool_call_result in tool_call_results
                 if tool_call_result.return_direct
+                and not tool_call_result.tool_output.is_error
             )
 
             # always finalize the agent, even if we're just handing off
@@ -469,14 +622,14 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
 
             # we don't want to stop the system if we're just handing off
             if return_direct_tool.tool_name != "handoff":
-                await ctx.set("current_tool_calls", [])
+                await ctx.store.set("current_tool_calls", [])
                 return StopEvent(result=result)
 
-        user_msg_str = await ctx.get("user_msg_str")
-        input_messages = memory.get(input=user_msg_str)
+        user_msg_str = await ctx.store.get("user_msg_str")
+        input_messages = await memory.aget(input=user_msg_str)
 
         # get this again, in case it changed
-        agent_name = await ctx.get("current_agent_name")
+        agent_name = await ctx.store.get("current_agent_name")
         agent = self.agents[agent_name]
 
         return AgentInput(input=input_messages, current_agent_name=agent.name)
@@ -489,17 +642,32 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         ctx: Optional[Context] = None,
         stepwise: bool = False,
         checkpoint_callback: Optional[CheckpointCallback] = None,
+        max_iterations: Optional[int] = None,
+        start_event: Optional[AgentWorkflowStartEvent] = None,
         **kwargs: Any,
     ) -> WorkflowHandler:
-        return super().run(
-            user_msg=user_msg,
-            chat_history=chat_history,
-            memory=memory,
-            ctx=ctx,
-            stepwise=stepwise,
-            checkpoint_callback=checkpoint_callback,
-            **kwargs,
-        )
+        # Detect if hitl is needed
+        if ctx is not None and ctx.is_running:
+            return super().run(
+                ctx=ctx,
+                stepwise=stepwise,
+                checkpoint_callback=checkpoint_callback,
+                **kwargs,
+            )
+        else:
+            start_event = start_event or AgentWorkflowStartEvent(
+                user_msg=user_msg,
+                chat_history=chat_history,
+                memory=memory,
+                max_iterations=max_iterations,
+                **kwargs,
+            )
+            return super().run(
+                start_event=start_event,
+                ctx=ctx,
+                stepwise=stepwise,
+                checkpoint_callback=checkpoint_callback,
+            )
 
     @classmethod
     def from_tools_or_functions(
@@ -509,10 +677,15 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
         system_prompt: Optional[str] = None,
         state_prompt: Optional[Union[str, BasePromptTemplate]] = None,
         initial_state: Optional[dict] = None,
+        output_cls: Optional[Type[BaseModel]] = None,
+        structured_output_fn: Optional[
+            Callable[[List[ChatMessage]], Dict[str, Any]]
+        ] = None,
         timeout: Optional[float] = None,
         verbose: bool = False,
     ) -> "AgentWorkflow":
-        """Initializes an AgentWorkflow from a list of tools or functions.
+        """
+        Initializes an AgentWorkflow from a list of tools or functions.
 
         The workflow will be initialized with a single agent that uses the provided tools or functions.
 
@@ -540,6 +713,8 @@ class AgentWorkflow(Workflow, PromptMixin, metaclass=AgentWorkflowMeta):
                     system_prompt=system_prompt,
                 )
             ],
+            output_cls=output_cls,
+            structured_output_fn=structured_output_fn,
             state_prompt=state_prompt,
             initial_state=initial_state,
             timeout=timeout,
