@@ -1,15 +1,17 @@
 """Base embeddings file."""
 
 import asyncio
+import uuid
 from abc import abstractmethod
 from enum import Enum
-from typing import Any, Callable, Coroutine, List, Optional, Sequence, Tuple
+from typing import Any, Callable, Coroutine, List, Optional, Sequence, Tuple, cast
+from typing_extensions import Self
 
 import numpy as np
 from llama_index.core.bridge.pydantic import (
     Field,
     ConfigDict,
-    field_validator,
+    model_validator,
 )
 from llama_index.core.callbacks.base import CallbackManager
 from llama_index.core.callbacks.schema import CBEventType, EventPayload
@@ -86,13 +88,23 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
         default=None,
         description="The number of workers to use for async embedding calls.",
     )
+    # Use Any to avoid import loops
+    embeddings_cache: Optional[Any] = Field(
+        default=None,
+        description="Cache for the embeddings: if None, the embeddings are not cached",
+    )
 
-    @field_validator("callback_manager")
-    @classmethod
-    def check_callback_manager(cls, v: CallbackManager) -> CallbackManager:
-        if v is None:
-            return CallbackManager([])
-        return v
+    @model_validator(mode="after")
+    def check_base_embeddings_class(self) -> Self:
+        from llama_index.core.storage.kvstore.types import BaseKVStore
+
+        if self.callback_manager is None:
+            self.callback_manager = CallbackManager([])
+        if self.embeddings_cache is not None and not isinstance(
+            self.embeddings_cache, BaseKVStore
+        ):
+            raise TypeError("embeddings_cache must be of type BaseKVStore")
+        return self
 
     @abstractmethod
     def _get_query_embedding(self, query: str) -> Embedding:
@@ -133,8 +145,22 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
         with self.callback_manager.event(
             CBEventType.EMBEDDING, payload={EventPayload.SERIALIZED: self.to_dict()}
         ) as event:
-            query_embedding = self._get_query_embedding(query)
-
+            if not self.embeddings_cache:
+                query_embedding = self._get_query_embedding(query)
+            elif self.embeddings_cache is not None:
+                cached_emb = self.embeddings_cache.get(
+                    key=query, collection="embeddings"
+                )
+                if cached_emb is not None:
+                    cached_key = next(iter(cached_emb.keys()))
+                    query_embedding = cached_emb[cached_key]
+                else:
+                    query_embedding = self._get_query_embedding(query)
+                    self.embeddings_cache.put(
+                        key=query,
+                        val={str(uuid.uuid4()): query_embedding},
+                        collection="embeddings",
+                    )
             event.on_end(
                 payload={
                     EventPayload.CHUNKS: [query],
@@ -162,7 +188,22 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
         with self.callback_manager.event(
             CBEventType.EMBEDDING, payload={EventPayload.SERIALIZED: self.to_dict()}
         ) as event:
-            query_embedding = await self._aget_query_embedding(query)
+            if not self.embeddings_cache:
+                query_embedding = await self._aget_query_embedding(query)
+            elif self.embeddings_cache is not None:
+                cached_emb = await self.embeddings_cache.aget(
+                    key=query, collection="embeddings"
+                )
+                if cached_emb is not None:
+                    cached_key = next(iter(cached_emb.keys()))
+                    query_embedding = cached_emb[cached_key]
+                else:
+                    query_embedding = await self._aget_query_embedding(query)
+                    await self.embeddings_cache.aput(
+                        key=query,
+                        val={str(uuid.uuid4()): query_embedding},
+                        collection="embeddings",
+                    )
 
             event.on_end(
                 payload={
@@ -237,6 +278,72 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
             *[self._aget_text_embedding(text) for text in texts]
         )
 
+    def _get_text_embeddings_cached(self, texts: List[str]) -> List[Embedding]:
+        """
+        Get text embeddings from cache. If not in cache, generate them.
+        """
+        if self.embeddings_cache is None:
+            raise ValueError("embeddings_cache must be defined")
+
+        embeddings: List[Optional[Embedding]] = [None for i in range(len(texts))]
+        # Tuples of (index, text) to be able to keep same order of embeddings
+        non_cached_texts: List[Tuple[int, str]] = []
+        for i, txt in enumerate(texts):
+            cached_emb = self.embeddings_cache.get(key=txt, collection="embeddings")
+            if cached_emb is not None:
+                cached_key = next(iter(cached_emb.keys()))
+                embeddings[i] = cached_emb[cached_key]
+            else:
+                non_cached_texts.append((i, txt))
+        if len(non_cached_texts) > 0:
+            text_embeddings = self._get_text_embeddings(
+                [x[1] for x in non_cached_texts]
+            )
+            for j, text_embedding in enumerate(text_embeddings):
+                orig_i = non_cached_texts[j][0]
+                embeddings[orig_i] = text_embedding
+
+                self.embeddings_cache.put(
+                    key=texts[orig_i],
+                    val={str(uuid.uuid4()): text_embedding},
+                    collection="embeddings",
+                )
+        return cast(List[Embedding], embeddings)
+
+    async def _aget_text_embeddings_cached(self, texts: List[str]) -> List[Embedding]:
+        """
+        Asynchronously get text embeddings from cache. If not in cache, generate them.
+        """
+        if self.embeddings_cache is None:
+            raise ValueError("embeddings_cache must be defined")
+
+        embeddings: List[Optional[Embedding]] = [None for i in range(len(texts))]
+        # Tuples of (index, text) to be able to keep same order of embeddings
+        non_cached_texts: List[Tuple[int, str]] = []
+        for i, txt in enumerate(texts):
+            cached_emb = await self.embeddings_cache.aget(
+                key=txt, collection="embeddings"
+            )
+            if cached_emb is not None:
+                cached_key = next(iter(cached_emb.keys()))
+                embeddings[i] = cached_emb[cached_key]
+            else:
+                non_cached_texts.append((i, txt))
+
+        if len(non_cached_texts) > 0:
+            text_embeddings = await self._aget_text_embeddings(
+                [x[1] for x in non_cached_texts]
+            )
+            for j, text_embedding in enumerate(text_embeddings):
+                orig_i = non_cached_texts[j][0]
+                embeddings[orig_i] = text_embedding
+                await self.embeddings_cache.aput(
+                    key=texts[orig_i],
+                    val={str(uuid.uuid4()): text_embedding},
+                    collection="embeddings",
+                )
+        return cast(List[Embedding], embeddings)
+
     @dispatcher.span
     def get_text_embedding(self, text: str) -> Embedding:
         """
@@ -257,7 +364,22 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
         with self.callback_manager.event(
             CBEventType.EMBEDDING, payload={EventPayload.SERIALIZED: self.to_dict()}
         ) as event:
-            text_embedding = self._get_text_embedding(text)
+            if not self.embeddings_cache:
+                text_embedding = self._get_text_embedding(text)
+            elif self.embeddings_cache is not None:
+                cached_emb = self.embeddings_cache.get(
+                    key=text, collection="embeddings"
+                )
+                if cached_emb is not None:
+                    cached_key = next(iter(cached_emb.keys()))
+                    text_embedding = cached_emb[cached_key]
+                else:
+                    text_embedding = self._get_text_embedding(text)
+                    self.embeddings_cache.put(
+                        key=text,
+                        val={str(uuid.uuid4()): text_embedding},
+                        collection="embeddings",
+                    )
 
             event.on_end(
                 payload={
@@ -286,7 +408,22 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
         with self.callback_manager.event(
             CBEventType.EMBEDDING, payload={EventPayload.SERIALIZED: self.to_dict()}
         ) as event:
-            text_embedding = await self._aget_text_embedding(text)
+            if not self.embeddings_cache:
+                text_embedding = await self._aget_text_embedding(text)
+            elif self.embeddings_cache is not None:
+                cached_emb = await self.embeddings_cache.aget(
+                    key=text, collection="embeddings"
+                )
+                if cached_emb is not None:
+                    cached_key = next(iter(cached_emb.keys()))
+                    text_embedding = cached_emb[cached_key]
+                else:
+                    text_embedding = await self._aget_text_embedding(text)
+                    await self.embeddings_cache.aput(
+                        key=text,
+                        val={str(uuid.uuid4()): text_embedding},
+                        collection="embeddings",
+                    )
 
             event.on_end(
                 payload={
@@ -332,7 +469,10 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
                     CBEventType.EMBEDDING,
                     payload={EventPayload.SERIALIZED: self.to_dict()},
                 ) as event:
-                    embeddings = self._get_text_embeddings(cur_batch)
+                    if not self.embeddings_cache:
+                        embeddings = self._get_text_embeddings(cur_batch)
+                    elif self.embeddings_cache is not None:
+                        embeddings = self._get_text_embeddings_cached(cur_batch)
                     result_embeddings.extend(embeddings)
                     event.on_end(
                         payload={
@@ -361,9 +501,10 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
         model_dict.pop("api_key", None)
 
         cur_batch: List[str] = []
-        callback_payloads: List[Tuple[str, List[str]]] = []
-        result_embeddings: List[Embedding] = []
         embeddings_coroutines: List[Coroutine] = []
+        callback_payloads: List[Tuple[str, List[str]]] = []
+
+        # for idx, text in queue_with_progress:
         for idx, text in enumerate(texts):
             cur_batch.append(text)
             if idx == len(texts) - 1 or len(cur_batch) == self.embed_batch_size:
@@ -378,21 +519,26 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
                     payload={EventPayload.SERIALIZED: self.to_dict()},
                 )
                 callback_payloads.append((event_id, cur_batch))
-                embeddings_coroutines.append(self._aget_text_embeddings(cur_batch))
+
+                if not self.embeddings_cache:
+                    embeddings_coroutines.append(self._aget_text_embeddings(cur_batch))
+                elif self.embeddings_cache is not None:
+                    embeddings_coroutines.append(
+                        self._aget_text_embeddings_cached(cur_batch)
+                    )
+
                 cur_batch = []
 
         # flatten the results of asyncio.gather, which is a list of embeddings lists
-        nested_embeddings = []
-
-        if num_workers and num_workers > 1:
-            nested_embeddings = await run_jobs(
-                embeddings_coroutines,
-                show_progress=show_progress,
-                workers=self.num_workers,
-                desc="Generating embeddings",
-            )
-        else:
-            if show_progress:
+        if len(embeddings_coroutines) > 0:
+            if num_workers and num_workers > 1:
+                nested_embeddings = await run_jobs(
+                    embeddings_coroutines,
+                    show_progress=show_progress,
+                    workers=self.num_workers,
+                    desc="Generating embeddings",
+                )
+            elif show_progress:
                 try:
                     from tqdm.asyncio import tqdm_asyncio
 
@@ -405,6 +551,8 @@ class BaseEmbedding(TransformComponent, DispatcherSpanMixin):
                     nested_embeddings = await asyncio.gather(*embeddings_coroutines)
             else:
                 nested_embeddings = await asyncio.gather(*embeddings_coroutines)
+        else:
+            nested_embeddings = []
 
         result_embeddings = [
             embedding for embeddings in nested_embeddings for embedding in embeddings
