@@ -1,4 +1,7 @@
 import os
+import base64
+from binascii import Error as BinasciiError
+from pathlib import Path
 from typing import Any, Awaitable, Callable, List, Optional, Sequence
 
 from llama_index.core.base.llms.types import (
@@ -10,7 +13,9 @@ from llama_index.core.base.llms.types import (
     CompletionResponseAsyncGen,
     CompletionResponseGen,
     MessageRole,
+    ImageBlock,
 )
+from llama_index.core.schema import ImageNode
 
 
 def messages_to_history_str(messages: Sequence[ChatMessage]) -> str:
@@ -108,9 +113,12 @@ def chat_response_to_completion_response(
     chat_response: ChatResponse,
 ) -> CompletionResponse:
     """Convert a chat response to a completion response."""
+    additional_kwargs = chat_response.message.additional_kwargs
+    additional_kwargs.update(chat_response.additional_kwargs)
+
     return CompletionResponse(
         text=chat_response.message.content or "",
-        additional_kwargs=chat_response.message.additional_kwargs,
+        additional_kwargs=additional_kwargs,
         raw=chat_response.raw,
     )
 
@@ -122,9 +130,12 @@ def stream_chat_response_to_completion_response(
 
     def gen() -> CompletionResponseGen:
         for response in chat_response_gen:
+            additional_kwargs = response.message.additional_kwargs
+            additional_kwargs.update(response.additional_kwargs)
+
             yield CompletionResponse(
                 text=response.message.content or "",
-                additional_kwargs=response.message.additional_kwargs,
+                additional_kwargs=additional_kwargs,
                 delta=response.delta,
                 raw=response.raw,
             )
@@ -133,7 +144,7 @@ def stream_chat_response_to_completion_response(
 
 
 def completion_to_chat_decorator(
-    func: Callable[..., CompletionResponse]
+    func: Callable[..., CompletionResponse],
 ) -> Callable[..., ChatResponse]:
     """Convert a completion function to a chat function."""
 
@@ -148,7 +159,7 @@ def completion_to_chat_decorator(
 
 
 def stream_completion_to_chat_decorator(
-    func: Callable[..., CompletionResponseGen]
+    func: Callable[..., CompletionResponseGen],
 ) -> Callable[..., ChatResponseGen]:
     """Convert a completion function to a chat function."""
 
@@ -163,7 +174,7 @@ def stream_completion_to_chat_decorator(
 
 
 def chat_to_completion_decorator(
-    func: Callable[..., ChatResponse]
+    func: Callable[..., ChatResponse],
 ) -> Callable[..., CompletionResponse]:
     """Convert a chat function to a completion function."""
 
@@ -178,7 +189,7 @@ def chat_to_completion_decorator(
 
 
 def stream_chat_to_completion_decorator(
-    func: Callable[..., ChatResponseGen]
+    func: Callable[..., ChatResponseGen],
 ) -> Callable[..., CompletionResponseGen]:
     """Convert a chat function to a completion function."""
 
@@ -196,7 +207,7 @@ def stream_chat_to_completion_decorator(
 
 
 def acompletion_to_chat_decorator(
-    func: Callable[..., Awaitable[CompletionResponse]]
+    func: Callable[..., Awaitable[CompletionResponse]],
 ) -> Callable[..., Awaitable[ChatResponse]]:
     """Convert a completion function to a chat function."""
 
@@ -211,7 +222,7 @@ def acompletion_to_chat_decorator(
 
 
 def achat_to_completion_decorator(
-    func: Callable[..., Awaitable[ChatResponse]]
+    func: Callable[..., Awaitable[ChatResponse]],
 ) -> Callable[..., Awaitable[CompletionResponse]]:
     """Convert a chat function to a completion function."""
 
@@ -226,7 +237,7 @@ def achat_to_completion_decorator(
 
 
 def astream_completion_to_chat_decorator(
-    func: Callable[..., Awaitable[CompletionResponseAsyncGen]]
+    func: Callable[..., Awaitable[CompletionResponseAsyncGen]],
 ) -> Callable[..., Awaitable[ChatResponseAsyncGen]]:
     """Convert a completion function to a chat function."""
 
@@ -243,7 +254,7 @@ def astream_completion_to_chat_decorator(
 
 
 def astream_chat_to_completion_decorator(
-    func: Callable[..., Awaitable[ChatResponseAsyncGen]]
+    func: Callable[..., Awaitable[ChatResponseAsyncGen]],
 ) -> Callable[..., Awaitable[CompletionResponseAsyncGen]]:
     """Convert a chat function to a completion function."""
 
@@ -284,9 +295,12 @@ def astream_chat_response_to_completion_response(
 
     async def gen() -> CompletionResponseAsyncGen:
         async for response in chat_response_gen:
+            additional_kwargs = response.message.additional_kwargs
+            additional_kwargs.update(response.additional_kwargs)
+
             yield CompletionResponse(
                 text=response.message.content or "",
-                additional_kwargs=response.message.additional_kwargs,
+                additional_kwargs=additional_kwargs,
                 delta=response.delta,
                 raw=response.raw,
             )
@@ -313,3 +327,40 @@ def get_from_param_or_env(
             f" `{env_key}` which contains it, or pass"
             f"  `{key}` as a named parameter."
         )
+
+
+def image_node_to_image_block(image_node: ImageNode) -> ImageBlock:
+    """
+    Get an ImageBlock from an ImageNode.
+
+    Args:
+        image_node (ImageNode): ImageNode to convert.
+
+    Returns:
+        ImageBlock: block representation of the node.
+
+    Raises:
+        ValueError: when the image provided within the ImageNode is not correctly base64-encoded.
+
+    """
+    if isinstance(image_node.image, str):
+        try:
+            return ImageBlock(image=base64.b64decode(image_node.image, validate=True))
+        except BinasciiError:
+            raise ValueError("The provided image string is not base64-encoded")
+    elif image_node.image is None:
+        if image_node.image_path is not None:
+            image_path: Optional[Path] = Path(image_node.image_path)
+        elif "file_path" in image_node.metadata:
+            image_path = image_node.metadata["file_path"]
+        else:
+            image_path = image_node.image_path
+        return ImageBlock(
+            image=image_node.image,
+            url=image_node.image_url,
+            image_mimetype=image_node.image_mimetype,
+            path=image_path,
+        )
+
+    else:
+        raise ValueError("image_node.image is neither a string or None.")
