@@ -10,6 +10,7 @@ from typing import (
     Annotated,
     Any,
     AsyncGenerator,
+    Dict,
     Generator,
     List,
     Literal,
@@ -40,6 +41,7 @@ class MessageRole(str, Enum):
     """Message role."""
 
     SYSTEM = "system"
+    DEVELOPER = "developer"
     USER = "user"
     ASSISTANT = "assistant"
     FUNCTION = "function"
@@ -49,11 +51,15 @@ class MessageRole(str, Enum):
 
 
 class TextBlock(BaseModel):
+    """A representation of text data to directly pass to/from the LLM."""
+
     block_type: Literal["text"] = "text"
     text: str
 
 
 class ImageBlock(BaseModel):
+    """A representation of image data to directly pass to/from the LLM."""
+
     block_type: Literal["image"] = "image"
     image: bytes | None = None
     path: FilePath | None = None
@@ -74,7 +80,8 @@ class ImageBlock(BaseModel):
 
     @model_validator(mode="after")
     def image_to_base64(self) -> Self:
-        """Store the image as base64 and guess the mimetype when possible.
+        """
+        Store the image as base64 and guess the mimetype when possible.
 
         In case the model was built passing image data but without a mimetype,
         we try to guess it using the filetype library. To avoid resource-intense
@@ -109,20 +116,33 @@ class ImageBlock(BaseModel):
             self.image_mimetype = guess.mime if guess else None
 
     def resolve_image(self, as_base64: bool = False) -> BytesIO:
-        """Resolve an image such that PIL can read it.
+        """
+        Resolve an image such that PIL can read it.
 
         Args:
             as_base64 (bool): whether the resolved image should be returned as base64-encoded bytes
+
         """
-        return resolve_binary(
+        data_buffer = resolve_binary(
             raw_bytes=self.image,
             path=self.path,
             url=str(self.url) if self.url else None,
             as_base64=as_base64,
         )
 
+        # Check size by seeking to end and getting position
+        data_buffer.seek(0, 2)  # Seek to end
+        size = data_buffer.tell()
+        data_buffer.seek(0)  # Reset to beginning
+
+        if size == 0:
+            raise ValueError("resolve_image returned zero bytes")
+        return data_buffer
+
 
 class AudioBlock(BaseModel):
+    """A representation of audio data to directly pass to/from the LLM."""
+
     block_type: Literal["audio"] = "audio"
     audio: bytes | None = None
     path: FilePath | None = None
@@ -139,7 +159,8 @@ class AudioBlock(BaseModel):
 
     @model_validator(mode="after")
     def audio_to_base64(self) -> Self:
-        """Store the audio as base64 and guess the mimetype when possible.
+        """
+        Store the audio as base64 and guess the mimetype when possible.
 
         In case the model was built passing audio data but without a mimetype,
         we try to guess it using the filetype library. To avoid resource-intense
@@ -166,21 +187,177 @@ class AudioBlock(BaseModel):
             self.format = guess.extension if guess else None
 
     def resolve_audio(self, as_base64: bool = False) -> BytesIO:
-        """Resolve an audio such that PIL can read it.
+        """
+        Resolve an audio such that PIL can read it.
 
         Args:
             as_base64 (bool): whether the resolved audio should be returned as base64-encoded bytes
+
         """
-        return resolve_binary(
+        data_buffer = resolve_binary(
             raw_bytes=self.audio,
             path=self.path,
             url=str(self.url) if self.url else None,
             as_base64=as_base64,
         )
+        # Check size by seeking to end and getting position
+        data_buffer.seek(0, 2)  # Seek to end
+        size = data_buffer.tell()
+        data_buffer.seek(0)  # Reset to beginning
+
+        if size == 0:
+            raise ValueError("resolve_image returned zero bytes")
+        return data_buffer
+
+
+class DocumentBlock(BaseModel):
+    """A representation of a document to directly pass to the LLM."""
+
+    block_type: Literal["document"] = "document"
+    data: Optional[bytes] = None
+    path: Optional[Union[FilePath | str]] = None
+    url: Optional[str] = None
+    title: Optional[str] = None
+    document_mimetype: Optional[str] = None
+
+    @model_validator(mode="after")
+    def document_validation(self) -> Self:
+        self.document_mimetype = self.document_mimetype or self._guess_mimetype()
+
+        if not self.title:
+            self.title = "input_document"
+
+        # skip data validation if it's not provided
+        if not self.data:
+            return self
+
+        try:
+            decoded_document = base64.b64decode(self.data, validate=True)
+        except BinasciiError:
+            self.data = base64.b64encode(self.data)
+
+        return self
+
+    def resolve_document(self) -> BytesIO:
+        """
+        Resolve a document such that it is represented by a BufferIO object.
+        """
+        data_buffer = resolve_binary(
+            raw_bytes=self.data,
+            path=self.path,
+            url=str(self.url) if self.url else None,
+            as_base64=False,
+        )
+        # Check size by seeking to end and getting position
+        data_buffer.seek(0, 2)  # Seek to end
+        size = data_buffer.tell()
+        data_buffer.seek(0)  # Reset to beginning
+
+        if size == 0:
+            raise ValueError("resolve_image returned zero bytes")
+        return data_buffer
+
+    def _get_b64_string(self, data_buffer: BytesIO) -> str:
+        """
+        Get base64-encoded string from a BytesIO buffer.
+        """
+        data = data_buffer.read()
+        return base64.b64encode(data).decode("utf-8")
+
+    def _get_b64_bytes(self, data_buffer: BytesIO) -> bytes:
+        """
+        Get base64-encoded bytes from a BytesIO buffer.
+        """
+        data = data_buffer.read()
+        return base64.b64encode(data)
+
+    def guess_format(self) -> str | None:
+        path = self.path or self.url
+        if not path:
+            return None
+
+        return Path(str(path)).suffix.replace(".", "")
+
+    def _guess_mimetype(self) -> str | None:
+        if self.data:
+            guess = filetype.guess(self.data)
+            return str(guess.mime) if guess else None
+
+        suffix = self.guess_format()
+        if not suffix:
+            return None
+
+        guess = filetype.get_type(ext=suffix)
+        return str(guess.mime) if guess else None
+
+
+class CacheControl(BaseModel):
+    type: str
+    ttl: str = Field(default="5m")
+
+
+class CachePoint(BaseModel):
+    """Used to set the point to cache up to, if the LLM supports caching."""
+
+    block_type: Literal["cache"] = "cache"
+    cache_control: CacheControl
+
+
+class CitableBlock(BaseModel):
+    """Supports providing citable content to LLMs that have built-in citation support."""
+
+    block_type: Literal["citable"] = "citable"
+    title: str
+    source: str
+    # TODO: We could maybe expand the types here,
+    # limiting for now to known use cases
+    content: List[
+        Annotated[
+            Union[TextBlock, ImageBlock, DocumentBlock],
+            Field(discriminator="block_type"),
+        ]
+    ]
+
+    @field_validator("content", mode="before")
+    @classmethod
+    def validate_content(cls, v: Any) -> Any:
+        if isinstance(v, str):
+            return [TextBlock(text=v)]
+
+        return v
+
+
+class CitationBlock(BaseModel):
+    """A representation of cited content from past messages."""
+
+    block_type: Literal["citation"] = "citation"
+    cited_content: Annotated[
+        Union[TextBlock, ImageBlock], Field(discriminator="block_type")
+    ]
+    source: str
+    title: str
+    additional_location_info: Dict[str, int]
+
+    @field_validator("cited_content", mode="before")
+    @classmethod
+    def validate_cited_content(cls, v: Any) -> Any:
+        if isinstance(v, str):
+            return TextBlock(text=v)
+
+        return v
 
 
 ContentBlock = Annotated[
-    Union[TextBlock, ImageBlock, AudioBlock], Field(discriminator="block_type")
+    Union[
+        TextBlock,
+        ImageBlock,
+        AudioBlock,
+        DocumentBlock,
+        CachePoint,
+        CitableBlock,
+        CitationBlock,
+    ],
+    Field(discriminator="block_type"),
 ]
 
 
@@ -192,7 +369,8 @@ class ChatMessage(BaseModel):
     blocks: list[ContentBlock] = Field(default_factory=list)
 
     def __init__(self, /, content: Any | None = None, **data: Any) -> None:
-        """Keeps backward compatibility with the old `content` field.
+        """
+        Keeps backward compatibility with the old `content` field.
 
         If content was passed and contained text, store a single TextBlock.
         If content was passed and it was a list, assume it's a list of content blocks and store it.
@@ -207,7 +385,8 @@ class ChatMessage(BaseModel):
 
     @model_validator(mode="after")
     def legacy_additional_kwargs_image(self) -> Self:
-        """Provided for backward compatibility.
+        """
+        Provided for backward compatibility.
 
         If `additional_kwargs` contains an `images` key, assume the value is a list
         of ImageDocument and convert them into image blocks.
@@ -221,24 +400,31 @@ class ChatMessage(BaseModel):
 
     @property
     def content(self) -> str | None:
-        """Keeps backward compatibility with the old `content` field.
+        """
+        Keeps backward compatibility with the old `content` field.
 
         Returns:
             The cumulative content of the TextBlock blocks, None if there are none.
+
         """
-        content = ""
+        content_strs = []
         for block in self.blocks:
             if isinstance(block, TextBlock):
-                content += block.text
+                content_strs.append(block.text)
 
-        return content or None
+        ct = "\n".join(content_strs) or None
+        if ct is None and len(content_strs) == 1:
+            return ""
+        return ct
 
     @content.setter
     def content(self, content: str) -> None:
-        """Keeps backward compatibility with the old `content` field.
+        """
+        Keeps backward compatibility with the old `content` field.
 
         Raises:
             ValueError: if blocks contains more than a block, or a block that's not TextBlock.
+
         """
         if not self.blocks:
             self.blocks = [TextBlock(text=content)]
