@@ -8,6 +8,7 @@ from llama_index.core.data_structs.data_structs import (
     IndexDict,
     IndexGraph,
     IndexList,
+    IndexLPG,
     IndexStruct,
     KeywordTable,
     MultiModelIndexDict,
@@ -24,6 +25,7 @@ INDEX_STRUCT_TYPE_TO_INDEX_STRUCT_CLASS: Dict[IndexStructType, Type[IndexStruct]
     IndexStructType.SQL: SQLStructTable,
     IndexStructType.PANDAS: PandasStructTable,
     IndexStructType.KG: KG,
+    IndexStructType.SIMPLE_LPG: IndexLPG,
     IndexStructType.EMPTY: EmptyIndexStruct,
     IndexStructType.DOCUMENT_SUMMARY: IndexDocumentSummary,
     IndexStructType.MULTIMODAL_VECTOR_STORE: MultiModelIndexDict,
