@@ -6,7 +6,7 @@ import sys
 from typing import Any
 
 
-def pip_install(package: str):
+def pip_install(package: str) -> None:
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
 
@@ -18,10 +18,9 @@ def download_integration(module_str: str, module_import_str: str, cls_name: str)
         raise Exception(f"Failed to pip install `{module_str}`") from e
 
     try:
-        exec(f"from {module_import_str} import {cls_name}")
         module_spec = importlib.util.find_spec(module_import_str)
-        module = importlib.util.module_from_spec(module_spec)
-        module_spec.loader.exec_module(module)
+        module = importlib.util.module_from_spec(module_spec)  # type: ignore
+        module_spec.loader.exec_module(module)  # type: ignore
         pack_cls = getattr(module, cls_name)
     except ImportError as e:
         raise ImportError(f"Unable to import {cls_name}") from e
