@@ -14,7 +14,8 @@ from llama_index.core.schema import ImageNode, TextNode
 
 
 class RetrieverEvaluator(BaseRetrievalEvaluator):
-    """Retriever evaluator.
+    """
+    Retriever evaluator.
 
     This module will evaluate a retriever using a set of metrics.
 
@@ -50,7 +51,8 @@ class RetrieverEvaluator(BaseRetrievalEvaluator):
 
 
 class MultiModalRetrieverEvaluator(BaseRetrievalEvaluator):
-    """Retriever evaluator.
+    """
+    Retriever evaluator.
 
     This module will evaluate a retriever using a set of metrics.
 
