@@ -9,7 +9,7 @@ from llama_index.core.base.base_retriever import BaseRetriever
 from llama_index.core.callbacks.base import CallbackManager
 from llama_index.core.chat_engine.types import BaseChatEngine, ChatMode
 from llama_index.core.data_structs.data_structs import IndexStruct
-from llama_index.core.ingestion import run_transformations
+from llama_index.core.ingestion import run_transformations, arun_transformations
 from llama_index.core.llms.utils import LLMType, resolve_llm
 from llama_index.core.schema import BaseNode, Document, IndexNode, TransformComponent
 from llama_index.core.settings import Settings
@@ -23,11 +23,13 @@ logger = logging.getLogger(__name__)
 
 
 class BaseIndex(Generic[IS], ABC):
-    """Base LlamaIndex.
+    """
+    Base LlamaIndex.
 
     Args:
         nodes (List[Node]): List of nodes to index
         show_progress (bool): Whether to show tqdm progress bars. Defaults to False.
+
     """
 
     index_struct_cls: Type[IS]
@@ -93,10 +95,11 @@ class BaseIndex(Generic[IS], ABC):
         transformations: Optional[List[TransformComponent]] = None,
         **kwargs: Any,
     ) -> IndexType:
-        """Create index from documents.
+        """
+        Create index from documents.
 
         Args:
-            documents (Optional[Sequence[BaseDocument]]): List of documents to
+            documents (Sequence[Document]]): List of documents to
                 build the index from.
 
         """
@@ -107,7 +110,7 @@ class BaseIndex(Generic[IS], ABC):
 
         with callback_manager.as_trace("index_construction"):
             for doc in documents:
-                docstore.set_document_hash(doc.get_doc_id(), doc.hash)
+                docstore.set_document_hash(doc.id_, doc.hash)
 
             nodes = run_transformations(
                 documents,  # type: ignore
@@ -136,7 +139,8 @@ class BaseIndex(Generic[IS], ABC):
         return self._index_struct.index_id
 
     def set_index_id(self, index_id: str) -> None:
-        """Set the index id.
+        """
+        Set the index id.
 
         NOTE: if you decide to set the index_id on the index_struct manually,
         you will need to explicitly call `add_index_struct` on the `index_store`
@@ -203,6 +207,25 @@ class BaseIndex(Generic[IS], ABC):
             self._insert(nodes, **insert_kwargs)
             self._storage_context.index_store.add_index_struct(self._index_struct)
 
+    async def ainsert_nodes(
+        self, nodes: Sequence[BaseNode], **insert_kwargs: Any
+    ) -> None:
+        """Asynchronously insert nodes."""
+        for node in nodes:
+            if isinstance(node, IndexNode):
+                try:
+                    node.dict()
+                except ValueError:
+                    self._object_map[node.index_id] = node.obj
+                    node.obj = None
+
+        with self._callback_manager.as_trace("ainsert_nodes"):
+            await self.docstore.async_add_documents(nodes, allow_update=True)
+            self._insert(nodes=nodes)
+            await self._storage_context.index_store.async_add_index_struct(
+                self._index_struct
+            )
+
     def insert(self, document: Document, **insert_kwargs: Any) -> None:
         """Insert a document."""
         with self._callback_manager.as_trace("insert"):
@@ -216,6 +239,19 @@ class BaseIndex(Generic[IS], ABC):
             self.insert_nodes(nodes, **insert_kwargs)
             self.docstore.set_document_hash(document.get_doc_id(), document.hash)
 
+    async def ainsert(self, document: Document, **insert_kwargs: Any) -> None:
+        """Asynchronously insert a document."""
+        with self._callback_manager.as_trace("ainsert"):
+            nodes = await arun_transformations(
+                [document],
+                self._transformations,
+                show_progress=self._show_progress,
+                **insert_kwargs,
+            )
+
+            await self.ainsert_nodes(nodes, **insert_kwargs)
+            await self.docstore.aset_document_hash(document.get_doc_id(), document.hash)
+
     @abstractmethod
     def _delete_node(self, node_id: str, **delete_kwargs: Any) -> None:
         """Delete a node."""
@@ -226,7 +262,8 @@ class BaseIndex(Generic[IS], ABC):
         delete_from_docstore: bool = False,
         **delete_kwargs: Any,
     ) -> None:
-        """Delete a list of nodes from the index.
+        """
+        Delete a list of nodes from the index.
 
         Args:
             doc_ids (List[str]): A list of doc_ids from the nodes to delete
@@ -239,8 +276,31 @@ class BaseIndex(Generic[IS], ABC):
 
         self._storage_context.index_store.add_index_struct(self._index_struct)
 
+    async def adelete_nodes(
+        self,
+        node_ids: List[str],
+        delete_from_docstore: bool = False,
+        **delete_kwargs: Any,
+    ) -> None:
+        """
+        Asynchronously delete a list of nodes from the index.
+
+        Args:
+            doc_ids (List[str]): A list of doc_ids from the nodes to delete
+
+        """
+        for node_id in node_ids:
+            self._delete_node(node_id, **delete_kwargs)
+            if delete_from_docstore:
+                await self.docstore.adelete_document(node_id, raise_error=False)
+
+        await self._storage_context.index_store.async_add_index_struct(
+            self._index_struct
+        )
+
     def delete(self, doc_id: str, **delete_kwargs: Any) -> None:
-        """Delete a document from the index.
+        """
+        Delete a document from the index.
         All nodes in the index related to the index will be deleted.
 
         Args:
@@ -250,6 +310,7 @@ class BaseIndex(Generic[IS], ABC):
         logger.warning(
             "delete() is now deprecated, please refer to delete_ref_doc() to delete "
             "ingested documents+nodes or delete_nodes to delete a list of nodes."
+            "Use adelete_ref_docs() for an asynchronous implementation"
         )
         self.delete_ref_doc(doc_id)
 
@@ -271,8 +332,27 @@ class BaseIndex(Generic[IS], ABC):
         if delete_from_docstore:
             self.docstore.delete_ref_doc(ref_doc_id, raise_error=False)
 
+    async def adelete_ref_doc(
+        self, ref_doc_id: str, delete_from_docstore: bool = False, **delete_kwargs: Any
+    ) -> None:
+        """Delete a document and it's nodes by using ref_doc_id."""
+        ref_doc_info = await self.docstore.aget_ref_doc_info(ref_doc_id)
+        if ref_doc_info is None:
+            logger.warning(f"ref_doc_id {ref_doc_id} not found, nothing deleted.")
+            return
+
+        await self.adelete_nodes(
+            ref_doc_info.node_ids,
+            delete_from_docstore=False,
+            **delete_kwargs,
+        )
+
+        if delete_from_docstore:
+            await self.docstore.adelete_ref_doc(ref_doc_id, raise_error=False)
+
     def update(self, document: Document, **update_kwargs: Any) -> None:
-        """Update a document and it's corresponding nodes.
+        """
+        Update a document and it's corresponding nodes.
 
         This is equivalent to deleting the document and then inserting it again.
 
@@ -285,11 +365,13 @@ class BaseIndex(Generic[IS], ABC):
         logger.warning(
             "update() is now deprecated, please refer to update_ref_doc() to update "
             "ingested documents+nodes."
+            "Use aupdate_ref_docs() for an asynchronous implementation"
         )
         self.update_ref_doc(document, **update_kwargs)
 
     def update_ref_doc(self, document: Document, **update_kwargs: Any) -> None:
-        """Update a document and it's corresponding nodes.
+        """
+        Update a document and it's corresponding nodes.
 
         This is equivalent to deleting the document and then inserting it again.
 
@@ -299,7 +381,7 @@ class BaseIndex(Generic[IS], ABC):
             delete_kwargs (Dict): kwargs to pass to delete
 
         """
-        with self._callback_manager.as_trace("update"):
+        with self._callback_manager.as_trace("update_ref_doc"):
             self.delete_ref_doc(
                 document.get_doc_id(),
                 delete_from_docstore=True,
@@ -307,10 +389,31 @@ class BaseIndex(Generic[IS], ABC):
             )
             self.insert(document, **update_kwargs.pop("insert_kwargs", {}))
 
+    async def aupdate_ref_doc(self, document: Document, **update_kwargs: Any) -> None:
+        """
+        Asynchronously update a document and it's corresponding nodes.
+
+        This is equivalent to deleting the document and then inserting it again.
+
+        Args:
+            document (Union[BaseDocument, BaseIndex]): document to update
+            insert_kwargs (Dict): kwargs to pass to insert
+            delete_kwargs (Dict): kwargs to pass to delete
+
+        """
+        with self._callback_manager.as_trace("aupdate_ref_doc"):
+            await self.adelete_ref_doc(
+                document.get_doc_id(),
+                delete_from_docstore=True,
+                **update_kwargs.pop("delete_kwargs", {}),
+            )
+            await self.ainsert(document, **update_kwargs.pop("insert_kwargs", {}))
+
     def refresh(
         self, documents: Sequence[Document], **update_kwargs: Any
     ) -> List[bool]:
-        """Refresh an index with documents that have changed.
+        """
+        Refresh an index with documents that have changed.
 
         This allows users to save LLM and Embedding model calls, while only
         updating documents that have any changes in text or metadata. It
@@ -319,19 +422,21 @@ class BaseIndex(Generic[IS], ABC):
         logger.warning(
             "refresh() is now deprecated, please refer to refresh_ref_docs() to "
             "refresh ingested documents+nodes with an updated list of documents."
+            "Use arefresh_ref_docs() for an asynchronous implementation"
         )
         return self.refresh_ref_docs(documents, **update_kwargs)
 
     def refresh_ref_docs(
         self, documents: Sequence[Document], **update_kwargs: Any
     ) -> List[bool]:
-        """Refresh an index with documents that have changed.
+        """
+        Refresh an index with documents that have changed.
 
         This allows users to save LLM and Embedding model calls, while only
         updating documents that have any changes in text or metadata. It
         will also insert any documents that previously were not stored.
         """
-        with self._callback_manager.as_trace("refresh"):
+        with self._callback_manager.as_trace("refresh_ref_docs"):
             refreshed_documents = [False] * len(documents)
             for i, document in enumerate(documents):
                 existing_doc_hash = self._docstore.get_document_hash(
@@ -348,6 +453,34 @@ class BaseIndex(Generic[IS], ABC):
 
             return refreshed_documents
 
+    async def arefresh_ref_docs(
+        self, documents: Sequence[Document], **update_kwargs: Any
+    ) -> List[bool]:
+        """
+        Asynchronously refresh an index with documents that have changed.
+
+        This allows users to save LLM and Embedding model calls, while only
+        updating documents that have any changes in text or metadata. It
+        will also insert any documents that previously were not stored.
+        """
+        with self._callback_manager.as_trace("arefresh_ref_docs"):
+            refreshed_documents = [False] * len(documents)
+            for i, document in enumerate(documents):
+                existing_doc_hash = await self._docstore.aget_document_hash(
+                    document.get_doc_id()
+                )
+                if existing_doc_hash is None:
+                    await self.ainsert(
+                        document, **update_kwargs.pop("insert_kwargs", {})
+                    )
+                    refreshed_documents[i] = True
+                elif existing_doc_hash != document.hash:
+                    await self.aupdate_ref_doc(
+                        document, **update_kwargs.pop("update_kwargs", {})
+                    )
+                    refreshed_documents[i] = True
+            return refreshed_documents
+
     @property
     @abstractmethod
     def ref_doc_info(self) -> Dict[str, RefDocInfo]:
@@ -355,13 +488,13 @@ class BaseIndex(Generic[IS], ABC):
         ...
 
     @abstractmethod
-    def as_retriever(self, **kwargs: Any) -> BaseRetriever:
-        ...
+    def as_retriever(self, **kwargs: Any) -> BaseRetriever: ...
 
     def as_query_engine(
         self, llm: Optional[LLMType] = None, **kwargs: Any
     ) -> BaseQueryEngine:
-        """Convert the index to a query engine.
+        """
+        Convert the index to a query engine.
 
         Calls `index.as_retriever(**kwargs)` to get the retriever and then wraps it in a
         `RetrieverQueryEngine.from_args(retriever, **kwrags)` call.
@@ -390,7 +523,8 @@ class BaseIndex(Generic[IS], ABC):
         llm: Optional[LLMType] = None,
         **kwargs: Any,
     ) -> BaseChatEngine:
-        """Convert the index to a chat engine.
+        """
+        Convert the index to a chat engine.
 
         Calls `index.as_query_engine(llm=llm, **kwargs)` to get the query engine and then
         wraps it in a chat engine based on the chat mode.
@@ -413,19 +547,11 @@ class BaseIndex(Generic[IS], ABC):
         query_engine = self.as_query_engine(llm=llm, **kwargs)
 
         # resolve chat mode
-        if chat_mode in [ChatMode.REACT, ChatMode.OPENAI, ChatMode.BEST]:
-            # use an agent with query engine tool in these chat modes
-            # NOTE: lazy import
-            from llama_index.core.agent import AgentRunner
-            from llama_index.core.tools.query_engine import QueryEngineTool
-
-            # convert query engine to tool
-            query_engine_tool = QueryEngineTool.from_defaults(query_engine=query_engine)
-
-            return AgentRunner.from_llm(
-                tools=[query_engine_tool],
-                llm=llm,
-                **kwargs,
+        if chat_mode in [ChatMode.REACT, ChatMode.OPENAI]:
+            raise ValueError(
+                "ChatMode.REACT and ChatMode.OPENAI are now deprecated and removed. "
+                "Please use the ReActAgent or FunctionAgent classes from llama_index.core.agent.workflow "
+                "to create an agent with a query engine tool."
             )
 
         if chat_mode == ChatMode.CONDENSE_QUESTION:
@@ -437,6 +563,7 @@ class BaseIndex(Generic[IS], ABC):
                 llm=llm,
                 **kwargs,
             )
+
         elif chat_mode == ChatMode.CONTEXT:
             from llama_index.core.chat_engine import ContextChatEngine
 
@@ -446,7 +573,7 @@ class BaseIndex(Generic[IS], ABC):
                 **kwargs,
             )
 
-        elif chat_mode == ChatMode.CONDENSE_PLUS_CONTEXT:
+        elif chat_mode in [ChatMode.CONDENSE_PLUS_CONTEXT, ChatMode.BEST]:
             from llama_index.core.chat_engine import CondensePlusContextChatEngine
 
             return CondensePlusContextChatEngine.from_defaults(
