@@ -11,6 +11,11 @@ from llama_index.core.base.llms.types import (
     MessageRole,
     TextBlock,
     AudioBlock,
+    DocumentBlock,
+    CachePoint,
+    CacheControl,
+    CitableBlock,
+    CitationBlock,
 )
 from llama_index.core.llms.custom import CustomLLM
 from llama_index.core.llms.llm import LLM
@@ -32,4 +37,9 @@ __all__ = [
     "ImageBlock",
     "TextBlock",
     "AudioBlock",
+    "DocumentBlock",
+    "CachePoint",
+    "CacheControl",
+    "CitableBlock",
+    "CitationBlock",
 ]
