@@ -36,7 +36,7 @@ def load_llm(data: dict) -> LLM:
     """Load LLM by name."""
     if isinstance(data, LLM):
         return data
-    llm_name = data.get("class_name", None)
+    llm_name = data.get("class_name")
     if llm_name is None:
         raise ValueError("LLM loading requires a class_name")
 
