@@ -71,8 +71,7 @@ class NodeParser(TransformComponent, ABC):
         nodes: Sequence[BaseNode],
         show_progress: bool = False,
         **kwargs: Any,
-    ) -> List[BaseNode]:
-        ...
+    ) -> List[BaseNode]: ...
 
     async def _aparse_nodes(
         self,
@@ -150,7 +149,8 @@ class NodeParser(TransformComponent, ABC):
         show_progress: bool = False,
         **kwargs: Any,
     ) -> List[BaseNode]:
-        """Parse documents into nodes.
+        """
+        Parse documents into nodes.
 
         Args:
             documents (Sequence[Document]): documents to parse
@@ -198,8 +198,7 @@ class NodeParser(TransformComponent, ABC):
 
 class TextSplitter(NodeParser):
     @abstractmethod
-    def split_text(self, text: str) -> List[str]:
-        ...
+    def split_text(self, text: str) -> List[str]: ...
 
     def split_texts(self, texts: List[str]) -> List[str]:
         nested_texts = [self.split_text(text) for text in texts]
@@ -222,8 +221,7 @@ class TextSplitter(NodeParser):
 
 class MetadataAwareTextSplitter(TextSplitter):
     @abstractmethod
-    def split_text_metadata_aware(self, text: str, metadata_str: str) -> List[str]:
-        ...
+    def split_text_metadata_aware(self, text: str, metadata_str: str) -> List[str]: ...
 
     def split_texts_metadata_aware(
         self, texts: List[str], metadata_strs: List[str]
