@@ -20,7 +20,7 @@ from llama_index.core.node_parser.text.utils import (
 from llama_index.core.utils import get_tokenizer
 
 SENTENCE_CHUNK_OVERLAP = 200
-CHUNKING_REGEX = "[^,.;。？！]+[,.;。？！]?"
+CHUNKING_REGEX = "[^,.;。？！]+[,.;。？！]?|[,.;。？！]"
 DEFAULT_PARAGRAPH_SEP = "\n\n\n"
 
 
@@ -32,7 +32,8 @@ class _Split:
 
 
 class SentenceSplitter(MetadataAwareTextSplitter):
-    """Parse text with a preference for complete sentences.
+    """
+    Parse text with a preference for complete sentences.
 
     In general, this class tries to keep sentences and paragraphs together. Therefore
     compared to the original TokenTextSplitter, there are less likely to be
@@ -195,7 +196,8 @@ class SentenceSplitter(MetadataAwareTextSplitter):
         return chunks
 
     def _split(self, text: str, chunk_size: int) -> List[_Split]:
-        r"""Break text into splits that are smaller than chunk size.
+        r"""
+        Break text into splits that are smaller than chunk size.
 
         The order of splitting is:
         1. split by paragraph separator
@@ -262,8 +264,9 @@ class SentenceSplitter(MetadataAwareTextSplitter):
                     cur_chunk.insert(0, (text, length))
                     last_index -= 1
 
-        while len(splits) > 0:
-            cur_split = splits[0]
+        split_idx = 0
+        while split_idx < len(splits):
+            cur_split = splits[split_idx]
             if cur_split.token_size > chunk_size:
                 raise ValueError("Single token exceeded chunk size")
             if cur_chunk_len + cur_split.token_size > chunk_size and not new_chunk:
@@ -278,7 +281,7 @@ class SentenceSplitter(MetadataAwareTextSplitter):
                     # add split to chunk
                     cur_chunk_len += cur_split.token_size
                     cur_chunk.append((cur_split.text, cur_split.token_size))
-                    splits.pop(0)
+                    split_idx += 1
                     new_chunk = False
                 else:
                     # close out chunk
@@ -293,7 +296,8 @@ class SentenceSplitter(MetadataAwareTextSplitter):
         return self._postprocess_chunks(chunks)
 
     def _postprocess_chunks(self, chunks: List[str]) -> List[str]:
-        """Post-process chunks.
+        """
+        Post-process chunks.
         Remove whitespace only chunks and remove leading and trailing whitespace.
         """
         new_chunks = []
