@@ -1,12 +1,12 @@
 """Output parsers."""
 
-from llama_index.core.output_parsers.base import ChainableOutputParser
+from llama_index.core.types import BaseOutputParser
 from llama_index.core.output_parsers.langchain import LangchainOutputParser
 from llama_index.core.output_parsers.pydantic import PydanticOutputParser
 from llama_index.core.output_parsers.selection import SelectionOutputParser
 
 __all__ = [
-    "ChainableOutputParser",
+    "BaseOutputParser",
     "LangchainOutputParser",
     "PydanticOutputParser",
     "SelectionOutputParser",
