@@ -1,4 +1,5 @@
 from llama_index.core.program.llm_program import LLMTextCompletionProgram
+from llama_index.core.program.function_program import FunctionCallingProgram
 from llama_index.core.program.multi_modal_llm_program import (
     MultiModalLLMCompletionProgram,
 )
@@ -8,4 +9,5 @@ __all__ = [
     "BasePydanticProgram",
     "LLMTextCompletionProgram",
     "MultiModalLLMCompletionProgram",
+    "FunctionCallingProgram",
 ]
