@@ -11,7 +11,9 @@ ALL_READERS: Dict[str, Type[BasePydanticReader]] = {
 def load_reader(data: Dict[str, Any]) -> BasePydanticReader:
     if isinstance(data, BasePydanticReader):
         return data
-    class_name = data.get("class_name", None)
+
+    class_name = data.get("class_name")
+
     if class_name is None:
         raise ValueError("Must specify `class_name` in reader data.")
 
