@@ -1,10 +1,7 @@
 """Init file."""
 
 from llama_index.core.response_synthesizers.accumulate import Accumulate
-from llama_index.core.response_synthesizers.base import (
-    BaseSynthesizer,
-    SynthesizerComponent,
-)
+from llama_index.core.response_synthesizers.base import BaseSynthesizer
 from llama_index.core.response_synthesizers.compact_and_refine import (
     CompactAndRefine,
 )
@@ -18,7 +15,6 @@ from llama_index.core.response_synthesizers.type import ResponseMode
 __all__ = [
     "ResponseMode",
     "BaseSynthesizer",
-    "SynthesizerComponent",
     "Refine",
     "SimpleSummarize",
     "TreeSummarize",
