@@ -32,6 +32,7 @@ import requests
 from dataclasses_json import DataClassJsonMixin
 from deprecated import deprecated
 from typing_extensions import Self
+from PIL import Image
 
 from llama_index.core.bridge.pydantic import (
     AnyUrl,
@@ -45,6 +46,7 @@ from llama_index.core.bridge.pydantic import (
     SerializeAsAny,
     SerializerFunctionWrapHandler,
     ValidationInfo,
+    field_serializer,
     field_validator,
     model_serializer,
 )
@@ -202,7 +204,8 @@ class TransformComponent(BaseComponent, DispatcherSpanMixin):
 
 
 class NodeRelationship(str, Enum):
-    """Node relationships used in `BaseNode` class.
+    """
+    Node relationships used in `BaseNode` class.
 
     Attributes:
         SOURCE: The node is the source document.
@@ -258,7 +261,8 @@ RelatedNodeType = Union[RelatedNodeInfo, List[RelatedNodeInfo]]
 
 # Node classes for indexes
 class BaseNode(BaseComponent):
-    """Base node Object.
+    """
+    Base node Object.
 
     Generic abstract interface for retrievable nodes
 
@@ -365,7 +369,8 @@ class BaseNode(BaseComponent):
 
     @property
     def source_node(self) -> Optional[RelatedNodeInfo]:
-        """Source object node.
+        """
+        Source object node.
 
         Extracted from the relationships field.
 
@@ -456,7 +461,8 @@ class BaseNode(BaseComponent):
         return f"Node ID: {self.node_id}\n{source_text_wrapped}"
 
     def get_embedding(self) -> List[float]:
-        """Get embedding.
+        """
+        Get embedding.
 
         Errors if embedding is None.
 
@@ -479,7 +485,8 @@ EmbeddingKind = Literal["sparse", "dense"]
 
 
 class MediaResource(BaseModel):
-    """A container class for media content.
+    """
+    A container class for media content.
 
     This class represents a generic media resource that can be stored and accessed
     in multiple ways - as raw bytes, on the filesystem, or via URL. It also supports
@@ -492,6 +499,7 @@ class MediaResource(BaseModel):
         mimetype: The MIME type indicating the format/type of the media content
         path: Local filesystem path where the media content can be accessed
         url: URL where the media content can be accessed remotely
+
     """
 
     embeddings: dict[EmbeddingKind, list[float]] | None = Field(
@@ -521,7 +529,8 @@ class MediaResource(BaseModel):
     @field_validator("data", mode="after")
     @classmethod
     def validate_data(cls, v: bytes | None, info: ValidationInfo) -> bytes | None:
-        """If binary data was passed, store the resource as base64 and guess the mimetype when possible.
+        """
+        If binary data was passed, store the resource as base64 and guess the mimetype when possible.
 
         In case the model was built passing binary data but without a mimetype,
         we try to guess it using the filetype library. To avoid resource-intense
@@ -565,9 +574,18 @@ class MediaResource(BaseModel):
 
         return v
 
+    @field_serializer("path")  # type: ignore
+    def serialize_path(
+        self, path: Optional[Path], _info: ValidationInfo
+    ) -> Optional[str]:
+        if path is None:
+            return path
+        return str(path)
+
     @property
     def hash(self) -> str:
-        """Generate a hash to uniquely identify the media resource.
+        """
+        Generate a hash to uniquely identify the media resource.
 
         The hash is generated based on the available content (data, path, text or url).
         Returns an empty string if no content is available.
@@ -622,7 +640,8 @@ class Node(BaseNode):
         return ObjectType.MULTIMODAL
 
     def get_content(self, metadata_mode: MetadataMode = MetadataMode.NONE) -> str:
-        """Get the text content for the node if available.
+        """
+        Get the text content for the node if available.
 
         Provided for backward compatibility, use self.text_resource directly instead.
         """
@@ -638,7 +657,8 @@ class Node(BaseNode):
         return ""
 
     def set_content(self, value: str) -> None:
-        """Set the text content of the node.
+        """
+        Set the text content of the node.
 
         Provided for backward compatibility, set self.text_resource instead.
         """
@@ -646,7 +666,15 @@ class Node(BaseNode):
 
     @property
     def hash(self) -> str:
+        """
+        Generate a hash representing the state of the node.
+
+        The hash is generated based on the available resources (audio, image, text or video) and its metadata.
+        """
         doc_identities = []
+        metadata_str = self.get_metadata_str(mode=MetadataMode.ALL)
+        if metadata_str:
+            doc_identities.append(metadata_str)
         if self.audio_resource is not None:
             doc_identities.append(self.audio_resource.hash)
         if self.image_resource is not None:
@@ -661,7 +689,8 @@ class Node(BaseNode):
 
 
 class TextNode(BaseNode):
-    """Provided for backward compatibility.
+    """
+    Provided for backward compatibility.
 
     Note: we keep the field with the typo "seperator" to maintain backward compatibility for
     serialized objects.
@@ -823,7 +852,7 @@ class ImageNode(TextNode):
             # load image from URL
             import requests
 
-            response = requests.get(self.image_url)
+            response = requests.get(self.image_url, timeout=(60, 60))
             return BytesIO(response.content)
         else:
             raise ValueError("No image found in node.")
@@ -841,7 +870,8 @@ class ImageNode(TextNode):
 
 
 class IndexNode(TextNode):
-    """Node with reference to any object.
+    """
+    Node with reference to any object.
 
     This can include other indices, query engines, retrievers.
 
@@ -980,13 +1010,15 @@ class NodeWithScore(BaseComponent):
 
 
 class Document(Node):
-    """Generic interface for a data document.
+    """
+    Generic interface for a data document.
 
     This document connects to data sources.
     """
 
     def __init__(self, **data: Any) -> None:
-        """Keeps backward compatibility with old 'Document' versions.
+        """
+        Keeps backward compatibility with old 'Document' versions.
 
         If 'text' was passed, store it in 'text_resource'.
         If 'doc_id' was passed, store it in 'id_'.
@@ -1008,7 +1040,7 @@ class Document(Node):
             else:
                 data["metadata"] = value
 
-        if "text" in data:
+        if data.get("text"):
             text = data.pop("text")
             if "text_resource" in data:
                 text_resource = (
@@ -1189,6 +1221,27 @@ class Document(Node):
         )
 
 
+def is_image_pil(file_path: str) -> bool:
+    try:
+        with Image.open(file_path) as img:
+            img.verify()  # Verify it's a valid image
+        return True
+    except (IOError, SyntaxError):
+        return False
+
+
+def is_image_url_pil(url: str) -> bool:
+    try:
+        response = requests.get(url, stream=True, timeout=(60, 60))
+        response.raise_for_status()  # Raise an exception for bad status codes
+        # Open image from the response content
+        img = Image.open(BytesIO(response.content))
+        img.verify()
+        return True
+    except (requests.RequestException, IOError, SyntaxError):
+        return False
+
+
 class ImageDocument(Document):
     """Backward compatible wrapper around Document containing an image."""
 
@@ -1204,10 +1257,14 @@ class ImageDocument(Document):
                 data=image, mimetype=image_mimetype
             )
         elif image_path:
+            if not is_image_pil(image_path):
+                raise ValueError("The specified file path is not an accessible image")
             kwargs["image_resource"] = MediaResource(
                 path=image_path, mimetype=image_mimetype
             )
         elif image_url:
+            if not is_image_url_pil(image_url):
+                raise ValueError("The specified URL is not an accessible image")
             kwargs["image_resource"] = MediaResource(
                 url=image_url, mimetype=image_mimetype
             )
@@ -1273,10 +1330,12 @@ class ImageDocument(Document):
         return "ImageDocument"
 
     def resolve_image(self, as_base64: bool = False) -> BytesIO:
-        """Resolve an image such that PIL can read it.
+        """
+        Resolve an image such that PIL can read it.
 
         Args:
             as_base64 (bool): whether the resolved image should be returned as base64-encoded bytes
+
         """
         if self.image_resource is None:
             return BytesIO()
@@ -1292,7 +1351,7 @@ class ImageDocument(Document):
             return BytesIO(img_bytes)
         elif self.image_resource.url is not None:
             # load image from URL
-            response = requests.get(str(self.image_resource.url))
+            response = requests.get(str(self.image_resource.url), timeout=(60, 60))
             img_bytes = response.content
             if as_base64:
                 return BytesIO(base64.b64encode(img_bytes))
@@ -1314,6 +1373,7 @@ class QueryBundle(DataClassJsonMixin):
         custom_embedding_strs (list[str]): list of strings used for embedding the query.
             This is currently used by all embedding-based queries.
         embedding (list[float]): the stored embedding for the query.
+
     """
 
     query_str: str
