@@ -1,10 +1,10 @@
-"""Ad-hoc data loader tool.
+"""
+Ad-hoc data loader tool.
 
 Tool that wraps any data loader, and is able to load data on-demand.
 
 """
 
-
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type
 
 from llama_index.core.bridge.pydantic import BaseModel
@@ -18,7 +18,8 @@ from llama_index.core.tools.utils import create_schema_from_function
 
 
 class OnDemandLoaderTool(AsyncBaseTool):
-    """On-demand data loader tool.
+    """
+    On-demand data loader tool.
 
     Loads data with by calling the provided loader function,
     stores in index, and queries for relevant data with a
@@ -147,7 +148,7 @@ class OnDemandLoaderTool(AsyncBaseTool):
         response = query_engine.query(query_str)
         return ToolOutput(
             content=str(response),
-            tool_name=self.metadata.name,
+            tool_name=self.metadata.get_name(),
             raw_input={"query": query_str},
             raw_output=response,
         )
@@ -162,7 +163,7 @@ class OnDemandLoaderTool(AsyncBaseTool):
         response = await query_engine.aquery(query_str)
         return ToolOutput(
             content=str(response),
-            tool_name=self.metadata.name,
+            tool_name=self.metadata.get_name(),
             raw_input={"query": query_str},
             raw_output=response,
         )
