@@ -12,6 +12,7 @@ from typing import (
     get_origin,
     get_args,
 )
+import datetime
 import typing
 
 from llama_index.core.bridge.pydantic import BaseModel, FieldInfo, create_model
@@ -25,10 +26,17 @@ def create_schema_from_function(
     ] = None,
     ignore_fields: Optional[List[str]] = None,
 ) -> Type[BaseModel]:
-    """Create schema from function."""
+    """
+    Create schema from function.
+    - Automatically adds json_schema_extra for basic Python types such as:
+        - datetime.date -> format: "date"
+        - datetime.datetime -> format: "date-time"
+        - datetime.time -> format: "time"
+    """
     fields = {}
     ignore_fields = ignore_fields or []
     params = signature(func).parameters
+
     for param_name in params:
         if param_name in ignore_fields:
             continue
@@ -36,28 +44,49 @@ def create_schema_from_function(
         param_type = params[param_name].annotation
         param_default = params[param_name].default
         description = None
+        json_schema_extra: dict[str, Any] = {}
 
         if get_origin(param_type) is typing.Annotated:
             args = get_args(param_type)
             param_type = args[0]
+
             if isinstance(args[1], str):
                 description = args[1]
             elif isinstance(args[1], FieldInfo):
                 description = args[1].description
+                if args[1].json_schema_extra and isinstance(
+                    args[1].json_schema_extra, dict
+                ):
+                    json_schema_extra.update(args[1].json_schema_extra)
+
+        # Add format based on param_type
+        if param_type == datetime.date:
+            json_schema_extra.setdefault("format", "date")
+        elif param_type == datetime.datetime:
+            json_schema_extra.setdefault("format", "date-time")
+        elif param_type == datetime.time:
+            json_schema_extra.setdefault("format", "time")
 
         if param_type is params[param_name].empty:
             param_type = Any
 
         if param_default is params[param_name].empty:
             # Required field
-            fields[param_name] = (param_type, FieldInfo(description=description))
+            fields[param_name] = (
+                param_type,
+                FieldInfo(description=description, json_schema_extra=json_schema_extra),
+            )
         elif isinstance(param_default, FieldInfo):
             # Field with pydantic.Field as default value
             fields[param_name] = (param_type, param_default)
         else:
             fields[param_name] = (
                 param_type,
-                FieldInfo(default=param_default, description=description),
+                FieldInfo(
+                    default=param_default,
+                    description=description,
+                    json_schema_extra=json_schema_extra,
+                ),
             )
 
     additional_fields = additional_fields or []
@@ -67,7 +96,6 @@ def create_schema_from_function(
             field_name, field_type, field_default = field_info
             fields[field_name] = (field_type, FieldInfo(default=field_default))
         elif len(field_info) == 2:
-            # Required field has no default value
             field_info = cast(Tuple[str, Type], field_info)
             field_name, field_type = field_info
             fields[field_name] = (field_type, FieldInfo())
